summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtorusedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtorusedit.h')
-rw-r--r--kpovmodeler/pmtorusedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmtorusedit.h b/kpovmodeler/pmtorusedit.h
index 95870664..e60256e3 100644
--- a/kpovmodeler/pmtorusedit.h
+++ b/kpovmodeler/pmtorusedit.h
@@ -39,9 +39,9 @@ class PMTorusEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMSphereEdit with tqparent and name
*/
- PMTorusEdit( TQWidget* tqparent, const char* name = 0 );
+ PMTorusEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMTorusEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMSphereEdit with tqparent and name
+ * Creates a PMSphereEdit with parent and name
*/